<?php
/**
 * Escutcheon functions and definitions
 *
 * @package Escutcheon
 */

if ( ! function_exists( 'escutcheon_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function escutcheon_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on escutcheon, use a find and replace
	 * to change 'escutcheon' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'escutcheon', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );


	// Adds image sizes.
	add_image_size( 'escutcheon-large', 1250, 9999, false );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'main'    => esc_html__( 'Main Menu', 'escutcheon' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'escutcheon_custom_background_args', array(
		'default-color' => '3e4244',
		'default-image' => '',
	) ) );
}
endif; // escutcheon_setup
add_action( 'after_setup_theme', 'escutcheon_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function escutcheon_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'escutcheon_content_width', 756 );
}
add_action( 'after_setup_theme', 'escutcheon_content_width', 0 );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function escutcheon_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'escutcheon' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'escutcheon_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function escutcheon_scripts() {
	wp_enqueue_style( 'escutcheon-style', get_stylesheet_uri() );

	wp_enqueue_script( 'escutcheon-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'escutcheon-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( wp_style_is( 'genericons', 'registered' ) ) {
		wp_enqueue_style( 'genericons' );
	} else {
		wp_enqueue_style( 'genericons', get_template_directory_uri() . '/fonts/genericons.css', array(), null );
	}

	wp_enqueue_style( 'escutcheon-fonts', escutcheon_fonts_url(), array(), null );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'escutcheon_scripts' );

/**
 * Register Google Fonts
 */
function escutcheon_fonts_url() {

	$fonts_url = '';

	/* Translators: If there are characters in your language that are not
	 * supported by Oswald, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$oswald = esc_html_x( 'on', 'Oswald font: on or off', 'escutcheon' );

	/* Translators: If there are characters in your language that are not
	 * supported by Alegreya Sans, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$alegreyasans = esc_html_x( 'on', 'Alegreya Sans font: on or off', 'escutcheon' );

	if ( 'off' !== $oswald || 'off' !== $alegreyasans ) {
		$font_families = array();

		if ( 'off' !== $oswald ) {
			$font_families[] = 'Oswald:400,300,700';
		}

		if ( 'off' !== $alegreyasans ) {
			$font_families[] = 'Alegreya Sans:400,400italic,700,700italic';
		}

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return $fonts_url;

}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';



